// Copyright (c) 2008, NTT DATA Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Globalization;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Validation;
using Microsoft.Practices.EnterpriseLibrary.Validation.Validators;
using TERASOLUNA.Fw.Common.Logging;
using TERASOLUNA.Fw.Common.Validation.Configuration;

namespace TERASOLUNA.Fw.Common.Validation.Validators
{
    /// <summary>
    /// ؃["t``FbN"ɑΉt``FbNs <see cref="Microsoft.Practices.EnterpriseLibrary.Validation.Validator"/> pNXłB
    /// </summary>
    /// <remarks>
    /// <para>
    /// ؑΏۂ̒l string ^A܂ string ^ɕϊ\łA
    /// t`ł邱Ƃ`FbN錟؋@\񋟂܂B
    ///  null ܂͋󕶎ɑ΂Ă͌؂͍sȂ߁A<seealso cref="ValueValidator.Negated"/> ̏ԂɊւ炸AKؐƂȂ܂B 
    /// </para>
    /// <para>
    /// ̃`FbNɗp郍WbNύXꍇAhNX쐬A<seealso cref="DateTimeFormatValidator.IsDateTime"/>
    /// \bhI[o[Ch܂B
    /// </para>
    /// <para>
    /// {NXpē͒l؂{ɂ́A͒lؐݒt@CɋLq
    ///  validator vf̑ƂāAȉ̐ݒs܂B
    /// ͒lؐݒt@Ĉ̋L@ɂẮA
    ///  Validation Application Block ̃hLgQƂĂB 
    /// </para>
    /// <para>
    /// <list type="bullet">
    /// <item>
    /// <description>negated</description>
    /// <para>؃[𔽓]tOłB true ݒ肵ꍇA؃[]܂BftHgĺA false łB</para>
    /// </item>
    /// <item>
    /// <description>messageTemplate</description>
    /// <para>؃G[bZ[W̃ev[gƂĎgp镶B
    /// ݒ̏ꍇ́A<seealso cref="DateTimeFormatValidator.DefaultNonNegatedMessageTemplate"/> A <seealso cref="DateTimeFormatValidator.DefaultNegatedMessageTemplate"/>  
    /// ꂩgp܂B
    /// </para>
    /// </item>
    /// <item>
    /// <description>messageTemplateResourceName</description>
    /// <para>bZ[Wev[g\[Xǂݍލۂ̖OB</para>
    /// </item>
    /// <item>
    /// <description>messageTemplateResourceType</description>
    /// <para>bZ[Wev[g\[Xǂݍލۂ̃\[X̌^B</para>
    /// </item>
    /// <item>
    /// <description>tag</description>
    /// <para>bZ[Wev[g̃v[Xz_ {2} ɓn镶B
    /// ؑΏۍڂ̘_w肵܂B</para>
    /// </item>
    /// <item>
    /// <description>type</description>
    /// <para>gp <see cref="Microsoft.Practices.EnterpriseLibrary.Validation.Validator"/> NX̌^SC^Ŏw肵܂B</para>
    /// </item>
    /// <item>
    /// <description>name</description>
    /// <para>gp <see cref="Microsoft.Practices.EnterpriseLibrary.Validation.Validator"/> ̖OłBt[[Nł͗p܂B
    /// ɕ <see cref="Microsoft.Practices.EnterpriseLibrary.Validation.Validator"/> 𗘗p؂sꍇAdOgp
    /// Ƃ͂ł܂B͕̑K{ڂłB</para>
    /// </item>
    /// </list>
    /// </para>
    /// <example>
    /// <code>
    /// &lt;validator negated="false"  
    /// messageTemplate="" messageTemplateResourceName=""
    /// messageTemplateResourceType="" tag="ؑΏۍږ" name="dateTimeFormat validator"  
    /// type="TERASOLUNA.Fw.Common.Validation.Validators.DateTimeFormatValidator,TERASOLUNA.Fw.Common"/&gt;
    /// </code>
    /// </example>
    /// </remarks>
    [ConfigurationElementType(typeof(DateTimeFormatValidatorData))]
    public class DateTimeFormatValidator : ValueValidator
    {
        /// <summary>
        /// <see cref="ILog"/> NX̃CX^XłB
        /// </summary>
        /// <remarks>
        /// Oo͂ɗp܂B
        /// </remarks>
        private static ILog _log = LogFactory.GetLogger(typeof(DateTimeFormatValidator));

        /// <summary>
        /// DateTime^ɕϊۂɎw肷t`łB
        /// </summary>
        /// <remarks>
        /// ftHgĺA null łB
        /// </remarks>
        private string _dateTimeFormat = null;

        /// <summary>
        /// RXgN^łBV <see cref="DateTimeFormatValidator"/> ̃CX^X܂B
        /// </summary>
        /// <param name="tag">ؑΏۂ̍ږB؎s̍ہAbZ[Wɗp܂B</param>
        /// <param name="messageTemplate">؎s̍ہAbZ[W𐶐邽߂ɗpev[gB
        /// ؂ɗpp[^v[Xz_ɓn܂B
        /// p[^Ƃ̃v[Xz_ԍ͈ȉ̒ʂłB
        /// <list type="table">
        /// <listheader>
        /// <term>v[Xz_</term>
        /// <description>e</description>
        /// </listheader>
        /// <item>
        /// <term>{0}</term>
        /// <description>ؑΏە</description>
        /// </item>
        /// <item>
        /// <term>{1}</term>
        /// <description>key(vpeBE\bh)</description>
        /// </item>
        /// <item>
        /// <term>{2}</term>
        /// <description>Tag</description>
        /// </item>
        /// </list>
        /// </param>
        /// <param name="negated">؏̔]tOB
        /// ]Ō؂{ꍇɂ true w肵܂B</param>
        /// <param name="dateTimeFormat"> DateTime ^ɕϊۂɎw肷t`B</param>
        /// <exception cref="ArgumentNullException">
        /// <paramref name="dateTimeFormat"/>  null QƂłB
        /// </exception>
        /// <exception cref="ArgumentException">
        /// <paramref name="dateTimeFormat"/> 󕶎łB
        /// </exception> 
        public DateTimeFormatValidator(string dateTimeFormat, string messageTemplate, string tag, bool negated)
            : base(messageTemplate, tag, negated)
        {
            if (dateTimeFormat == null)
            {
                ArgumentNullException exception = new ArgumentNullException("dateTimeFormat");
                if (_log.IsErrorEnabled)
                {
                    _log.Error(string.Format(
                        Properties.Resources.E_NULL_ARGUMENT, "dateTimeFormat"), exception);
                }
                throw exception;
            }

            if (dateTimeFormat.Length == 0)
            {
                string message = string.Format(Properties.Resources.E_EMPTY_STRING, "dateTimeFormat");
                ArgumentException exception = new ArgumentException(message);
                if (_log.IsErrorEnabled)
                {
                    _log.Error(message, exception);
                }
                throw exception;
            }

            _dateTimeFormat = dateTimeFormat;
        }

        /// <summary>
        /// <seealso cref="ValueValidator.Negated"/>  true łꍇɎgpftHg̃bZ[Wev[g擾܂B
        /// </summary>
        /// <value>؃[]̃ftHgbZ[Wev[gB</value>
        protected override string DefaultNegatedMessageTemplate
        {
            get { return Properties.Resources.DATE_TIME_FORMAT_VALIDATOR_NEGATED_MESSAGETEMPLATE; }
        }

        /// <summary>
        /// <seealso cref="ValueValidator.Negated"/>  false łꍇɎgpftHg̃bZ[Wev[g擾܂B
        /// </summary>
        /// <value>ftHgbZ[Wev[gB</value>
        protected override string DefaultNonNegatedMessageTemplate
        {
            get { return Properties.Resources.DATE_TIME_FORMAT_VALIDATOR_NONNEGATED_MESSAGETEMPLATE; }
        }

        /// <summary>
        /// ؃G[bZ[W𐶐郁\bhłB<seealso cref="Validator.MessageTemplate"/> ev[gƂA
        /// ݂̃J`ɏ]ĕtH[}bg܂B
        /// </summary>
        /// <remarks>
        /// <para>tH[}bgɊ܂܂v[Xz_ɓńAȉ̒ʂłB
        /// <para>
        /// <list type="table">
        /// <listheader>
        /// <term>v[Xz_</term>
        /// <description>e</description>
        /// </listheader>
        /// <item>
        /// <term>{0}</term>
        /// <description>ؑΏە</description>
        /// </item>
        /// <item>
        /// <term>{1}</term>
        /// <description>key(vpeBE\bh)</description>
        /// </item>
        /// <item>
        /// <term>{2}</term>
        /// <description>Tag</description>
        /// </item>
        /// <item>
        /// <term>{3}</term>
        /// <description>t`</description>
        /// </item>
        /// </list>
        /// </para>
        /// </para>
        /// </remarks>
        /// <exception cref="FormatException">
        /// <see cref="Validator.MessageTemplate"/>  4 ȏ̃v[Xz_LqĂꍇB
        /// </exception>
        /// <param name="objectToValidate">ؑΏۂ̃IuWFNgB</param>
        /// <param name="key">IuWFNg擾vpeB܂̓\bhB</param>
        /// <returns>؃G[bZ[WB</returns>
        protected override string GetMessage(object objectToValidate, string key)
        {
            return string.Format(CultureInfo.CurrentUICulture,
                this.MessageTemplate,
                objectToValidate,
                key,
                this.Tag,
                _dateTimeFormat);
        }

        /// <summary>
        /// t``FbNs\bhłBؑΏےl̕\A
        /// t`łȂꍇA؎sƂȂ܂B
        /// </summary>
        /// <remarks>
        /// <para>
        /// <paramref name="objectToValidate"/>  null ܂͋󕶎̏ꍇA؏͍s܂B
        /// </para>
        /// </remarks>
        /// <exception cref="ArgumentNullException">
        /// <list type="bullet">
        /// <item>
        /// <paramref name="validationResults"/>  null QƂłB
        /// </item>
        /// </list>
        /// </exception>  
        /// <param name="objectToValidate">ؑΏۂ̒lB</param>
        /// <param name="currentTarget">ؑΏۂ̃IuWFNgB</param>
        /// <param name="key">ؑΏۂ̃vpeB܂̓\bhB</param>
        /// <param name="validationResults">،ʂi[ <see cref="ValidationResults"/> B</param>
        protected override void DoValidate(object objectToValidate,
                                           object currentTarget,
                                           string key,
                                           ValidationResults validationResults)
        {
            if (validationResults == null)
            {
                ArgumentNullException exception = new ArgumentNullException("validationResults");
                if (_log.IsErrorEnabled)
                {
                    _log.Error(string.Format(
                        Properties.Resources.E_NULL_ARGUMENT, "validationResults"), exception);
                }
                throw exception;
            }

            if (objectToValidate == null || string.IsNullOrEmpty(objectToValidate.ToString()))
            {
                return;
            }

            if (IsDateTime(objectToValidate.ToString()) == Negated)
            {
                LogValidationResult(validationResults,
                                    GetMessage(objectToValidate, key),
                                    currentTarget,
                                    key);
            }

        }

        /// <summary>
        /// <paramref name="str"/> t`̕ł邩ǂ𔻒肵܂B
        /// </summary>
        /// <param name="str">ΏەB</param>
        /// <returns><paramref name="str"/> t`łꍇ true AłȂꍇ false B</returns>
        protected virtual bool IsDateTime(string str)
        {
            DateTime dt = new DateTime();
            return DateTime.TryParseExact(str, _dateTimeFormat, CultureInfo.CurrentUICulture, DateTimeStyles.None, out dt);
        }
    }
}
